@@ -13,16 +13,18 @@ no Moose;
 
 sub _build_tmpl_params ($self) {
     return {
-        dist_name        => $self->zilla->name,
-        dist_path        => lc $self->zilla->name,
-        module_name      => $self->zilla->name =~ s[-][::]smgr,
-        module_path      => $self->zilla->name =~ s[-][/]smgr,
-        main_script      => 'main.pl',
-        author           => $self->zilla->stash_named('%User')->{'name'},
-        author_email     => $self->zilla->stash_named('%User')->{'email'},
-        copyright_year   => P->date->now->year,
-        copyright_holder => $self->zilla->stash_named('%Rights')->{'copyright_holder'},
-        license          => $self->zilla->stash_named('%Rights')->{'license_class'},
+        dist_name          => $self->zilla->name,
+        dist_path          => lc $self->zilla->name,
+        module_name        => $self->zilla->name =~ s[-][::]smgr,
+        module_path        => $self->zilla->name =~ s[-][/]smgr,
+        main_script        => 'main.pl',
+        author             => $self->zilla->stash_named('%User')->{'name'},
+        author_email       => $self->zilla->stash_named('%User')->{'email'},
+        copyright_year     => P->date->now->year,
+        copyright_holder   => $self->zilla->stash_named('%Rights')->{'copyright_holder'},
+        license            => $self->zilla->stash_named('%Rights')->{'license_class'},
+        bitbucket_username => $self->zilla->stash_named('%Pcore::Bitbucket') ? $self->zilla->stash_named('%Pcore::Bitbucket')->username : 'username',
+        dockerhub_username => $self->zilla->stash_named('%Pcore::DockerHub') ? $self->zilla->stash_named('%Pcore::DockerHub')->username : 'username',
     };
 }
 
