@@ -1,4 +1,4 @@
-package Pcore v0.11.4;
+package Pcore v0.11.5;
 
 use v5.20.2;
 use utf8;
@@ -518,11 +518,11 @@ sub _configure_console {
 
     # setup default layers for STD* handles clones
     if ($MSWIN) {
-        require PerlIO::via::Win32UnicodeConsole;
+        require Pcore::Core::PerlIOviaWin32UnicodeConsole;
 
-        binmode $STDIN,  qq[:raw:crlf:encoding($Pcore::ENCODING_CONSOLE)] or die;
-        binmode $STDOUT, q[:raw:via(Win32UnicodeConsole)]                 or die;
-        binmode $STDERR, q[:raw:via(Win32UnicodeConsole)]                 or die;
+        binmode $STDIN,  qq[:raw:crlf:encoding($Pcore::ENCODING_CONSOLE)]       or die;
+        binmode $STDOUT, q[:raw:via(Pcore::Core::PerlIOviaWin32UnicodeConsole)] or die;
+        binmode $STDERR, q[:raw:via(Pcore::Core::PerlIOviaWin32UnicodeConsole)] or die;
 
         select $STDOUT;    ## no critic qw(InputOutput::ProhibitOneArgSelect)
     }
@@ -574,6 +574,12 @@ __END__
 
 Pcore - perl applications development environment
 
+=begin HTML
+
+<p><a href="https://metacpan.org/pod/Pcore" target="_blank"><img alt="CPAN version" src="https://badge.fury.io/pl/Pcore.svg"></a></p>
+
+=end HTML
+
 =head1 SYNOPSIS
 
     use Pcore qw[-<pragma> <import>], {config};
