@@ -24,4 +24,12 @@ __END__
 
 =encoding utf8
 
+=head1 NAME
+
+Pcore::Core::Log::Channel
+
+=head1 SYNOPSIS
+
+=head1 DESCRIPTION
+
 =cut
