@@ -1,8 +1,9 @@
 package Pcore::HTTP::UA;
 
-BEGIN {
-    use Const::Fast;
+use Pcore qw[-class];
+use Const::Fast;
 
+BEGIN {
     const our $TLS_CTX_LOW  => 1;
     const our $TLS_CTX_HIGH => 2;
     const our $TLS_CTX      => {
@@ -11,9 +12,8 @@ BEGIN {
     };
 }
 
-use Pcore qw[-class];
-use AnyEvent::Handle();
-use Errno();
+use AnyEvent::Handle qw[];
+use Errno qw[];
 use HTTP::Parser::XS qw[HEADERS_AS_ARRAYREF];
 use Pcore::HTTP::Message::Headers;
 use Pcore::HTTP::Request;
@@ -1350,3 +1350,16 @@ sub _socks_handshake {
 ##
 ## -----SOURCE FILTER LOG END-----
 __END__
+=pod
+
+=encoding utf8
+
+=head1 NAME
+
+Pcore::HTTP::UA
+
+=head1 SYNOPSIS
+
+=head1 DESCRIPTION
+
+=cut
