@@ -1,7 +1,7 @@
 package Pcore::Util::Digest;
 
 use Pcore;
-use Digest();    ## no critic qw(Modules::ProhibitEvilModules)
+use Digest qw[];    ## no critic qw(Modules::ProhibitEvilModules)
 
 my $BCRYPT_COST_DEFAULT = 10;
 
