@@ -2,7 +2,7 @@ package Pcore::Util::File;
 
 use Pcore;
 use Fcntl qw[:DEFAULT];
-use Cwd();    ## no critic qw(Modules::ProhibitEvilModules)
+use Cwd qw[];    ## no critic qw(Modules::ProhibitEvilModules)
 use Pcore::Util::File::Path;
 
 # PATH OBJECT CONSTRUCTOR
