@@ -1,7 +1,7 @@
 package Pcore::Util::File::TempFile;
 
 use Pcore qw[-class];
-use File::Temp();    ## no critic qw(Modules::ProhibitEvilModules)
+use File::Temp qw[];    ## no critic qw(Modules::ProhibitEvilModules)
 
 has base     => ( is => 'lazy', isa => Str );
 has tmpl     => ( is => 'lazy', isa => Str );
@@ -58,3 +58,16 @@ sub _build_tmpl {
 
 1;
 __END__
+=pod
+
+=encoding utf8
+
+=head1 NAME
+
+Pcore::Util::File::TempFile
+
+=head1 SYNOPSIS
+
+=head1 DESCRIPTION
+
+=cut
